@@ -34,7 +34,7 @@ class TestActionsBase(tests_base.TestCase):
     def test__get_baremetal_client(self, mock_client, mock_endpoint, mock_cxt):
         mock_endpoint.return_value = mock.Mock(
             url='http://ironic/v1', region='ironic-region')
-        self.action._get_baremetal_client()
+        self.action.get_baremetal_client()
         mock_client.assert_called_once_with(
             'http://ironic/v1', max_retries=12, os_ironic_api_version='1.15',
             region_name='ironic-region', retry_interval=5, token=mock.ANY)
