@@ -21,7 +21,7 @@ from tripleo_common.tests import base
 class SwiftTempUrlActionTest(base.TestCase):
     @mock.patch('time.time')
     @mock.patch('uuid.uuid4')
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch('mistral.context.ctx')
     def _test_get_tempurl(self, secret, mock_ctx, mock_get_object_client,
                           mock_uuid, mock_time):
